@@ -8,7 +8,7 @@ Many of them might be moved to python-gammu later
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
+Copyright © 2003 - 2010 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -411,8 +411,6 @@ Conn_Cable = [
     'fbus',
     'mbus',
     'fbuspl2303',
-    'phonetblue',
-    'fbusblue',
     ]
 Conn_IrDA_Win = [
     'irdaphonet',
@@ -477,6 +475,10 @@ else:
         '/dev/ttyUSB1',
         '/dev/ttyACM0',
         '/dev/ttyACM1',
+        '/dev/cua0',
+        '/dev/cua1',
+        '/dev/cuaU0',
+        '/dev/cuaU1',
         '/dev/ircomm0',
         '/dev/rfcomm0',
         '/dev/usb/tts/0',
@@ -485,6 +487,8 @@ else:
         (Conn_Cable, '/dev/ttyS%d', (0, 3), ['serial']),
         (Conn_Cable, '/dev/ttyUSB%d', (0, 3), ['serial', 'usb']),
         (Conn_Cable, '/dev/ttyACM%d', (0, 3), ['serial', 'usb']),
+        (Conn_Cable, '/dev/cuaU%d', (0, 3), ['serial', 'usb']),
+        (Conn_Cable, '/dev/cua%d', (0, 3), ['serial', 'usb']),
         (Conn_BlueRF, '/dev/rfrcomm%d', (0, 1), ['bluetooth']),
         (Conn_IrDA_Other, '/dev/ircomm%d', (0, 1), ['irda']),
         (Conn_Cable, '/dev/usb/tts/%d', (0, 3), ['serial', 'usb']),
@@ -588,6 +592,20 @@ ManufacturerMap = {
     'Fly': 26,
     'Simcom': 27,
     'Sanyo': 28,
+    'ZTE': 29,
+    'Jinpeng': 30,
+    'Emgeton': 31,
+    'Hughes': 32,
+    'SciPhone': 33,
+    'Gionee': 34,
+    'Openmoko': 35,
+    'Vodafone': 36,
+    'CECT': 37,
+    'Matsunichi': 38,
+    'Foston': 39,
+    'Daxian': 40,
+    'Sandshine': 41,
+    'Sonim': 42,
 }
 GarbleMap = {
     0: 'atdot',
