@@ -7,7 +7,7 @@ Main Wammu window
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
+Copyright © 2003 - 2010 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -295,7 +295,7 @@ class WammuFrame(wx.Frame):
         menu2.Append(201, _('&Connect'), _('Connect the device.'))
         menu2.Append(202, _('&Disconnect'), _('Disconnect the device.'))
         menu2.AppendSeparator()
-        menu2.Append(210, _('&Synchronise time'), _('Synchronise time in mobile with PC.'))
+        menu2.Append(210, _('&Synchronise time'), _('Synchronise time in phone with PC.'))
         menu2.AppendSeparator()
         menu2.Append(250, _('Send &file'), _('Send file to phone.'))
         # Add menu to the menu bar
@@ -839,7 +839,7 @@ class WammuFrame(wx.Frame):
         if self.connected:
             connection_settings = {
                 'Connection': self.cfg.Read('/Gammu/Connection'),
-                'LockDevice': self.cfg.Read('/Gammu/LockDevice'),
+                'LockDevice': self.cfg.ReadBool('/Gammu/LockDevice'),
                 'Device': self.cfg.Read('/Gammu/Device'),
                 'Model': self.cfg.Read('/Gammu/Model')
             }
@@ -849,7 +849,7 @@ class WammuFrame(wx.Frame):
             if self.connected:
                 connection_settings_new = {
                     'Connection': self.cfg.Read('/Gammu/Connection'),
-                    'LockDevice': self.cfg.Read('/Gammu/LockDevice'),
+                    'LockDevice': self.cfg.ReadBool('/Gammu/LockDevice'),
                     'Device': self.cfg.Read('/Gammu/Device'),
                     'Model': self.cfg.Read('/Gammu/Model')
                 }
@@ -960,7 +960,7 @@ class WammuFrame(wx.Frame):
                 if len(d) == 2:
                     text += u'<b>%s</b>: %s<br>' % (d[0], d[1])
                 else:
-                    text += u'<br>%s' % d[0]
+                    text += u'<p>%s</p>' % d[0]
         self.content.SetContent(text)
 
     def OnShow(self, evt):
@@ -1500,7 +1500,6 @@ class WammuFrame(wx.Frame):
                 if datatype == 'message':
                     smsl = []
                     for v in backup:
-                        v['Folder'] = 2 # FIXME: this should be configurable
                         v['SMSC']['Location'] = 1
                         (v['Location'], v['Folder']) = self.sm.AddSMS(v)
                         # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
@@ -1587,6 +1586,7 @@ class WammuFrame(wx.Frame):
                 if datatype == 'PhonePhonebook':
                     for v in backup['PhonePhonebook']:
                         v['Location'] = self.sm.AddMemory(v)
+                        time.sleep(0.5)
                         # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                         v = self.sm.GetMemory(v['MemoryType'], v['Location'])
                         Wammu.Utils.ParseMemoryEntry(v, self.cfg)
@@ -1597,6 +1597,7 @@ class WammuFrame(wx.Frame):
                 elif datatype == 'SIMPhonebook':
                     for v in backup['SIMPhonebook']:
                         v['Location'] = self.sm.AddMemory(v)
+                        time.sleep(0.5)
                         # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                         v = self.sm.GetMemory(v['MemoryType'], v['Location'])
                         Wammu.Utils.ParseMemoryEntry(v, self.cfg)
@@ -1607,6 +1608,7 @@ class WammuFrame(wx.Frame):
                 elif datatype == 'ToDo':
                     for v in backup['ToDo']:
                         v['Location'] = self.sm.AddToDo(v)
+                        time.sleep(0.5)
                         # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                         v = self.sm.GetToDo(v['Location'])
                         Wammu.Utils.ParseTodo(v)
@@ -1617,6 +1619,7 @@ class WammuFrame(wx.Frame):
                 elif datatype == 'Calendar':
                     for v in backup['Calendar']:
                         v['Location'] = self.sm.AddCalendar(v)
+                        time.sleep(0.5)
                         # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                         v = self.sm.GetCalendar(v['Location'])
                         Wammu.Utils.ParseCalendar(v)
@@ -2082,18 +2085,20 @@ class WammuFrame(wx.Frame):
                 wx.OK | wx.ICON_ERROR).ShowModal()
             return
         cfg = {
-            'StartInfo': self.cfg.Read('/Gammu/StartInfo'),
-            'UseGlobalDebugFile': 1,
+            'StartInfo': self.cfg.ReadBool('/Gammu/StartInfo'),
+            'UseGlobalDebugFile': True,
             'DebugFile': None, # Set on other place
-            'SyncTime': self.cfg.Read('/Gammu/SyncTime'),
+            'SyncTime': self.cfg.ReadBool('/Gammu/SyncTime'),
             'Connection': config['Connection'],
-            'LockDevice': self.cfg.Read('/Gammu/LockDevice'),
+            'LockDevice': self.cfg.ReadBool('/Gammu/LockDevice'),
             'DebugLevel': 'textalldate', # Set on other place
             'Device': config['Device'],
             'Model': config['Model'],
             }
-        if cfg['Model'] == 'auto':
-            cfg['Model'] = ''
+
+        # Compatibility with old Gammu versions
+        cfg = Wammu.Utils.CompatConfig(cfg)
+
         self.sm.SetConfig(0, cfg)
         try:
             self.sm.Init()
@@ -2135,6 +2140,16 @@ class WammuFrame(wx.Frame):
             except gammu.GSMError, val:
                 pass
 
+        # Check for PIN
+        code = self.sm.GetSecurityStatus()
+        if code is not None:
+            dlg = wx.PasswordEntryDialog(self,
+                _('Please enter %s code:') % code,
+                _('Phone asks for security code'))
+            if dlg.ShowModal() == wx.ID_OK:
+                self.sm.EnterSecurityCode(code, dlg.GetValue())
+
+
     def DBUSActionCallback(self, id, action):
         '''
         Called when user does something on notification.
@@ -2202,6 +2217,13 @@ class WammuFrame(wx.Frame):
         wx.PostEvent(self.searchlog, evt)
 
     def SearchPhone(self, evt = None):
+        if self.connected:
+            wx.MessageDialog(self,
+                _('Searching for phone can not be performed while you are connected to phone, please disconnect first.'),
+                _('You are connected to phone!'),
+                wx.OK | wx.ICON_ERROR).ShowModal()
+            return
+
         index = self.cfg.gammu.FirstFree()
         result = Wammu.PhoneWizard.RunConfigureWizard(self, index)
         if result is not None:
@@ -2215,19 +2237,19 @@ class WammuFrame(wx.Frame):
         Wammu.Webbrowser.Open("http://%swammu.eu/?version=%s" % (Wammu.Utils.GetWebsiteLang(), Wammu.__version__))
 
     def Support(self, evt = None):
-        Wammu.Webbrowser.Open("http://%swammu.eu/support?version=%s" % (Wammu.Utils.GetWebsiteLang(), Wammu.__version__))
+        Wammu.Webbrowser.Open("http://%swammu.eu/support/?version=%s" % (Wammu.Utils.GetWebsiteLang(), Wammu.__version__))
 
     def ReportBug(self, evt = None):
         Wammu.Webbrowser.Open("http://bugs.cihar.com/set_project.php?ref=bug_report_page.php&project_id=1")
 
     def PhoneDB(self, evt = None):
-        Wammu.Webbrowser.Open("http://%scihar.com/gammu/phonedb" % Wammu.Utils.GetWebsiteLang())
+        Wammu.Webbrowser.Open("http://%swammu.eu/phones/" % Wammu.Utils.GetWebsiteLang())
 
     def Talkback(self, evt = None):
         Wammu.TalkbackDialog.DoTalkback(self, self.cfg, 0)
 
     def Donate(self, evt = None):
-        Wammu.Webbrowser.Open("http://%swammu.eu/donate?src=wammu" % Wammu.Utils.GetWebsiteLang())
+        Wammu.Webbrowser.Open("http://%swammu.eu/donate/?src=wammu" % Wammu.Utils.GetWebsiteLang())
 
     def SaveLog(self, evt = None):
         '''
